package com.ruoyi.web.modules.industrypolicy.mapper;

import java.util.List;
import com.ruoyi.web.modules.industrypolicy.domain.BizSubsidyProject;

/**
 * 项目与补贴-项目 Mapper
 */
public interface BizSubsidyProjectMapper
{
    BizSubsidyProject selectBizSubsidyProjectById(Long id);

    List<BizSubsidyProject> selectBizSubsidyProjectList(BizSubsidyProject query);

    int insertBizSubsidyProject(BizSubsidyProject row);

    int updateBizSubsidyProject(BizSubsidyProject row);

    int updateBizSubsidyProjectExecStatus(BizSubsidyProject row);

    int deleteBizSubsidyProjectByIds(Long[] ids);
}
